# Generated by Django 4.2.11 on 2024-03-24 15:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0019_pdftype_cut_off_above_lines_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='pdftype',
            old_name='endoscopy_info_line',
            new_name='endoscope_info_line',
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-09 11:02

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0041_gender_patientmedication_medication_indication_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='CaseTemplateRuleType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='CaseTemplateRuleValue',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True, null=True)),
                ('fk_value', models.CharField(blank=True, max_length=255, null=True)),
                ('numeric_value', models.FloatField(blank=True, null=True)),
                ('text_value', models.CharField(blank=True, max_length=255, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='CaseTemplateRuleValueType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='CaseTemplateType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='CaseTemplateRule',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('name_de', models.CharField(max_length=255, null=True)),
                ('name_en', models.CharField(max_length=255, null=True)),
                ('description', models.TextField(blank=True, null=True)),
                ('value_type', models.CharField(blank=True, max_length=255, null=True)),
                ('chained_rules', models.ManyToManyField(related_name='calling_rules', to='endoreg_db.casetemplaterule')),
                ('rule_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.casetemplateruletype')),
                ('rule_values', models.ManyToManyField(related_name='rules', to='endoreg_db.casetemplaterulevalue')),
            ],
        ),
        migrations.CreateModel(
            name='CaseTemplate',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True, null=True)),
                ('case_template_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='case_templates', to='endoreg_db.casetemplatetype')),
                ('rules', models.ManyToManyField(to='endoreg_db.casetemplaterule')),
                ('secondary_rules', models.ManyToManyField(related_name='secondary_rules', to='endoreg_db.casetemplaterule')),
            ],
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-09 20:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0002_rawvideofile'),
    ]

    operations = [
        migrations.AddField(
            model_name='rawvideofile',
            name='frames_required',
            field=models.BooleanField(default=True),
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-09 17:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='RawVideoFile',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('uuid', models.UUIDField()),
                ('file', models.FileField(upload_to='raw_data/')),
                ('original_file_name', models.CharField(max_length=255)),
                ('hash', models.CharField(max_length=255, unique=True)),
                ('uploaded_at', models.DateTimeField(auto_now_add=True)),
                ('state_frames_extracted', models.BooleanField(default=False)),
                ('frame_dir', models.CharField(max_length=255)),
            ],
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-24 14:13

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0017_firstname_lastname_center_first_names_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='ReportReaderFlag',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('value', models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name='ReportReaderConfig',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('locale', models.CharField(default='de_DE', max_length=10)),
                ('text_date_format', models.CharField(default='%d.%m.%Y', max_length=10)),
                ('cut_off_above', models.ManyToManyField(related_name='report_reader_configs_cut_off_above', to='endoreg_db.reportreaderflag')),
                ('cut_off_below', models.ManyToManyField(related_name='report_reader_configs_cut_off_below', to='endoreg_db.reportreaderflag')),
                ('endoscope_info_line_flag', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='report_reader_configs_endoscope_info_line', to='endoreg_db.reportreaderflag')),
                ('examiner_info_line_flag', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='report_reader_configs_examiner_info_line', to='endoreg_db.reportreaderflag')),
                ('first_names', models.ManyToManyField(related_name='report_reader_configs', to='endoreg_db.firstname')),
                ('last_names', models.ManyToManyField(related_name='report_reader_configs', to='endoreg_db.lastname')),
                ('patient_info_line_flag', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='report_reader_configs_patient_info_line', to='endoreg_db.reportreaderflag')),
            ],
        ),
    ]



# Generated by Django 5.0.4 on 2024-06-24 10:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0064_casetemplaterule_extra_parameters_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='casetemplaterule',
            old_name='_date_value_distribution',
            new_name='date_value_distribution',
        ),
        migrations.RenameField(
            model_name='casetemplaterule',
            old_name='_multiple_categorical_value_distribution',
            new_name='multiple_categorical_value_distribution',
        ),
        migrations.RenameField(
            model_name='casetemplaterule',
            old_name='_numerical_value_distribution',
            new_name='numerical_value_distribution',
        ),
        migrations.RenameField(
            model_name='casetemplaterule',
            old_name='_single_categorical_value_distribution',
            new_name='single_categorical_value_distribution',
        ),
        migrations.RenameField(
            model_name='labvalue',
            old_name='_default_date_value_distribution',
            new_name='default_date_value_distribution',
        ),
        migrations.RenameField(
            model_name='labvalue',
            old_name='_default_multiple_categorical_value_distribution',
            new_name='default_multiple_categorical_value_distribution',
        ),
        migrations.RenameField(
            model_name='labvalue',
            old_name='_default_numerical_value_distribution',
            new_name='default_numerical_value_distribution',
        ),
        migrations.RenameField(
            model_name='labvalue',
            old_name='_default_single_categorical_value_distribution',
            new_name='default_single_categorical_value_distribution',
        ),
        migrations.AlterField(
            model_name='casetemplate',
            name='name',
            field=models.CharField(max_length=255, unique=True),
        ),
    ]



# Generated by Django 4.2.10 on 2024-08-10 12:39

import django.core.files.storage
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0067_alter_medicationindication_indication_type'),
    ]

    operations = [
        migrations.CreateModel(
            name='NetworkDeviceType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.CharField(max_length=255)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
            ],
            options={
                'db_table': 'network_device_types',
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='NetworkDeviceTypeManager',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
        ),
        migrations.AlterField(
            model_name='rawpdffile',
            name='file',
            field=models.FileField(storage=django.core.files.storage.FileSystemStorage(location='/home/agl-admin/agl-home-django/endoreg_home/endoreg_home/erc_data/raw_pdf'), upload_to='raw_pdf/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])]),
        ),
        migrations.CreateModel(
            name='NetworkDevice',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('ip', models.GenericIPAddressField(blank=True, null=True)),
                ('description', models.CharField(max_length=255)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('device_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.networkdevicetype')),
            ],
            options={
                'db_table': 'network_devices',
                'ordering': ['name'],
            },
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-27 08:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0027_labvalue_abbreviation_labvalue_default_normal_range_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='unit',
            name='abbreviation',
            field=models.CharField(blank=True, max_length=25, null=True),
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-10 14:03

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0052_rename_case_template_type_casetemplate_template_type'),
    ]

    operations = [
        migrations.CreateModel(
            name='PatientLabSampleType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('name_de', models.CharField(max_length=255, null=True)),
                ('name_en', models.CharField(max_length=255, null=True)),
                ('description', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='PatientLabSample',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateTimeField()),
                ('patient', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='lab_samples', to='endoreg_db.patient')),
                ('sample_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.patientlabsampletype')),
            ],
        ),
        migrations.AddField(
            model_name='patientlabvalue',
            name='sample',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.patientlabsample'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-09 07:44

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0037_alter_medicationindication_sources'),
    ]

    operations = [
        migrations.CreateModel(
            name='EmissionFactor',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('name_de', models.CharField(max_length=255, null=True)),
                ('name_en', models.CharField(max_length=255, null=True)),
                ('value', models.FloatField()),
                ('unit', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.unit')),
            ],
        ),
        migrations.CreateModel(
            name='Material',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('name_de', models.CharField(max_length=255, null=True)),
                ('name_en', models.CharField(max_length=255, null=True)),
                ('emission_factor', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.emissionfactor')),
            ],
        ),
        migrations.CreateModel(
            name='Product',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('name_de', models.CharField(max_length=255, null=True)),
                ('name_en', models.CharField(max_length=255, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='ProductGroup',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('name_de', models.CharField(max_length=255, null=True)),
                ('name_en', models.CharField(max_length=255, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Resource',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('name_de', models.CharField(max_length=255, null=True)),
                ('name_en', models.CharField(max_length=255, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Waste',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('name_de', models.CharField(max_length=255, null=True)),
                ('name_en', models.CharField(max_length=255, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='TransportRoute',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('distance', models.FloatField()),
                ('name', models.CharField(max_length=255)),
                ('name_de', models.CharField(max_length=255, null=True)),
                ('name_en', models.CharField(max_length=255, null=True)),
                ('emission_factor', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.emissionfactor')),
                ('unit', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.unit')),
            ],
        ),
        migrations.CreateModel(
            name='ReferenceProduct',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('emission_factor_package', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='reference_product_package', to='endoreg_db.emissionfactor')),
                ('emission_factor_product', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='reference_product_product', to='endoreg_db.emissionfactor')),
                ('emission_factor_total', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.emissionfactor')),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.product')),
                ('product_group', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='reference_product', to='endoreg_db.productgroup')),
            ],
        ),
        migrations.CreateModel(
            name='ProductWeight',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, null=True)),
                ('measured', models.FloatField(null=True)),
                ('verified', models.FloatField(null=True)),
                ('manufacturer', models.FloatField(null=True)),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.product')),
                ('unit', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.unit')),
            ],
        ),
        migrations.CreateModel(
            name='ProductMaterial',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('component', models.CharField(max_length=255)),
                ('quantity', models.FloatField()),
                ('material', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.material')),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='product_materials', to='endoreg_db.product')),
                ('unit', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.unit')),
            ],
        ),
        migrations.AddField(
            model_name='product',
            name='product_group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.productgroup'),
        ),
        migrations.AddField(
            model_name='product',
            name='transport_route',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.transportroute'),
        ),
        migrations.CreateModel(
            name='CenterWaste',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('year', models.IntegerField()),
                ('quantity', models.FloatField()),
                ('center', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.center')),
                ('emission_factor', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.emissionfactor')),
                ('unit', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.unit')),
                ('waste', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.waste')),
            ],
        ),
        migrations.CreateModel(
            name='CenterResource',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, null=True)),
                ('name_de', models.CharField(max_length=255, null=True)),
                ('name_en', models.CharField(max_length=255, null=True)),
                ('quantity', models.FloatField()),
                ('year', models.IntegerField()),
                ('center', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.center')),
                ('resource', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.resource')),
                ('transport_emission_factor', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='center_resource_transport_emission_factor', to='endoreg_db.emissionfactor')),
                ('unit', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.unit')),
                ('use_emission_factor', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='center_resource_use_emission_factor', to='endoreg_db.emissionfactor')),
            ],
        ),
        migrations.CreateModel(
            name='CenterProduct',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date_used', models.DateField()),
                ('center', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.center')),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.product')),
            ],
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-24 20:27

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0021_alter_pdftype_endoscope_info_line'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pdftype',
            name='endoscope_info_line',
            field=models.ForeignKey(default='', on_delete=django.db.models.deletion.CASCADE, related_name='pdf_type_endoscopy_info_line', to='endoreg_db.reportreaderflag'),
        ),
    ]



# Generated by Django 4.2.13 on 2024-05-30 04:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0034_alter_rawpdffile_file'),
    ]

    operations = [
        migrations.AlterField(
            model_name='medicationindication',
            name='sources',
            field=models.ManyToManyField(blank=True, null=True, to='endoreg_db.informationsource'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-09 07:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0038_emissionfactor_material_product_productgroup_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='referenceproduct',
            name='name',
            field=models.CharField(default='', max_length=255),
            preserve_default=False,
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-27 09:14

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0028_alter_unit_abbreviation'),
    ]

    operations = [
        migrations.CreateModel(
            name='MedicationIntakeTime',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('repeats', models.CharField(default='daily', max_length=20)),
                ('time', models.TimeField()),
                ('unit', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.unit')),
            ],
        ),
        migrations.RemoveField(
            model_name='patientmedication',
            name='medication',
        ),
        migrations.RemoveField(
            model_name='patientmedication',
            name='name',
        ),
        migrations.RemoveField(
            model_name='patientmedication',
            name='name_de',
        ),
        migrations.RemoveField(
            model_name='patientmedication',
            name='name_en',
        ),
        migrations.AddField(
            model_name='medication',
            name='adapt_to_liver_function',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='medication',
            name='adapt_to_renal_function',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='patientlabvalue',
            name='normal_range',
            field=models.JSONField(default={}),
        ),
        migrations.AddField(
            model_name='patientmedication',
            name='patient',
            field=models.ForeignKey(default=None, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.patient'),
            preserve_default=False,
        ),
        migrations.CreateModel(
            name='MedicationSchedule',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('intake_times', models.ManyToManyField(to='endoreg_db.medicationintaketime')),
                ('medication', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.medication')),
                ('unit', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.unit')),
            ],
        ),
        migrations.AddField(
            model_name='patientmedication',
            name='medication_schedules',
            field=models.ManyToManyField(to='endoreg_db.medicationschedule'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-29 07:38

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0029_medicationintaketime_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='MedicationIndicationType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('name_de', models.CharField(blank=True, max_length=255, null=True)),
                ('name_en', models.CharField(blank=True, max_length=255, null=True)),
            ],
        ),
        migrations.RemoveField(
            model_name='medicationintaketime',
            name='unit',
        ),
        migrations.AddField(
            model_name='informationsource',
            name='date',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='informationsource',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='informationsource',
            name='url',
            field=models.URLField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='medicationintaketime',
            name='name',
            field=models.CharField(default=None, max_length=255),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='medicationintaketime',
            name='name_de',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='medicationintaketime',
            name='name_en',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='medicationschedule',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='medicationschedule',
            name='dose',
            field=models.FloatField(default=1),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='medicationschedule',
            name='name_de',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='medicationschedule',
            name='name_en',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='medicationschedule',
            name='therapy_duration_d',
            field=models.DurationField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='patientlabvalue',
            name='normal_range',
            field=models.JSONField(default=dict),
        ),
        migrations.CreateModel(
            name='MedicationIndication',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('classification_choices', models.ManyToManyField(to='endoreg_db.diseaseclassificationchoice')),
                ('diseases', models.ManyToManyField(to='endoreg_db.disease')),
                ('events', models.ManyToManyField(to='endoreg_db.event')),
                ('indication_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.medicationindicationtype')),
                ('medication_schedules', models.ManyToManyField(to='endoreg_db.medicationschedule')),
            ],
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-09 08:50

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0039_referenceproduct_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='QuizAnswerType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='QuizQuestionType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='QuizQuestion',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField()),
                ('description', models.TextField(blank=True, null=True)),
                ('question_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.quizquestiontype')),
            ],
        ),
        migrations.CreateModel(
            name='QuizAnswer',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text_value', models.CharField(blank=True, max_length=255, null=True)),
                ('number_value', models.FloatField(blank=True, null=True)),
                ('last_updated', models.DateTimeField(auto_now=True)),
                ('answer_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.quizanswertype')),
                ('question', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.quizquestion')),
            ],
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-09 11:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0048_remove_casetemplaterule_chained_rules_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='casetemplaterule',
            name='rule_values',
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-24 12:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0016_rawpdffile_state_report_processing_required'),
    ]

    operations = [
        migrations.CreateModel(
            name='FirstName',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name='LastName',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
            ],
        ),
        migrations.AddField(
            model_name='center',
            name='first_names',
            field=models.ManyToManyField(related_name='centers', to='endoreg_db.firstname'),
        ),
        migrations.AddField(
            model_name='center',
            name='last_names',
            field=models.ManyToManyField(related_name='centers', to='endoreg_db.lastname'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-29 07:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0030_medicationindicationtype_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='medication',
            old_name='adapt_to_liver_function',
            new_name='adapt_to_age',
        ),
        migrations.AddField(
            model_name='medication',
            name='adapt_to_hepatic_function',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='medication',
            name='adapt_to_indication',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='medication',
            name='adapt_to_risk',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='medication',
            name='adapt_to_weight',
            field=models.BooleanField(default=False),
        ),
    ]



# Generated by Django 5.0.4 on 2024-06-20 17:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0062_labvalue_numeric_precision'),
    ]

    operations = [
        migrations.AlterField(
            model_name='labvalue',
            name='numeric_precision',
            field=models.IntegerField(default=3),
        ),
    ]



# Generated by Django 5.0.4 on 2024-06-20 17:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0061_remove_patientlabvalue_date_patientlabvalue_datetime'),
    ]

    operations = [
        migrations.AddField(
            model_name='labvalue',
            name='numeric_precision',
            field=models.CharField(default='.2f', max_length=5),
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-09 11:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0047_casetemplaterule_target_model'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='casetemplaterule',
            name='chained_rules',
        ),
        migrations.AddField(
            model_name='casetemplaterule',
            name='calling_rules',
            field=models.ManyToManyField(related_name='chained_rules', to='endoreg_db.casetemplaterule'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-24 10:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0015_rename_report_processed_rawpdffile_state_report_processed_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='rawpdffile',
            name='state_report_processing_required',
            field=models.BooleanField(default=True),
        ),
    ]



# Generated by Django 5.0.4 on 2024-06-10 19:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0053_patientlabsampletype_patientlabsample_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='MultipleCategoricalValueDistribution',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('categories', models.JSONField()),
                ('min_count', models.IntegerField()),
                ('max_count', models.IntegerField()),
                ('count_distribution_type', models.CharField(choices=[('uniform', 'Uniform'), ('normal', 'Normal')], max_length=20)),
                ('count_mean', models.FloatField(blank=True, null=True)),
                ('count_std_dev', models.FloatField(blank=True, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NumericValueDistribution',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('distribution_type', models.CharField(choices=[('uniform', 'Uniform'), ('normal', 'Normal'), ('skewed_normal', 'Skewed Normal')], max_length=20)),
                ('min_value', models.FloatField()),
                ('max_value', models.FloatField()),
                ('mean', models.FloatField(blank=True, null=True)),
                ('std_dev', models.FloatField(blank=True, null=True)),
                ('skewness', models.FloatField(blank=True, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SingleCategoricalValueDistribution',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('categories', models.JSONField()),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.RemoveField(
            model_name='casetemplaterulevalue',
            name='target_field',
        ),
        migrations.RemoveField(
            model_name='casetemplaterulevalue',
            name='value_type',
        ),
        migrations.AddField(
            model_name='casetemplaterule',
            name='target_field',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-09 12:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0049_remove_casetemplaterule_rule_values'),
    ]

    operations = [
        migrations.AddField(
            model_name='casetemplaterule',
            name='rule_values',
            field=models.ManyToManyField(related_name='rules', to='endoreg_db.casetemplaterulevalue'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-18 23:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0011_rawvideofile_state_sensitive_data_retrieved'),
    ]

    operations = [
        migrations.AddField(
            model_name='rawvideofile',
            name='prediction_dir',
            field=models.CharField(default='.', max_length=255),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_anonym_video_performed',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_anonym_video_required',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_dataset_complete',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_finalized',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_follow_up_intervention_available',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_follow_up_intervention_required',
            field=models.BooleanField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_histology_available',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_histology_required',
            field=models.BooleanField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_initial_prediction_completed',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_initial_prediction_import_completed',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_initial_prediction_import_required',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_initial_prediction_required',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_ocr_completed',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_ocr_required',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_ocr_result_validated',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_original_reports_deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_original_video_deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_outside_validated',
            field=models.BooleanField(default=False),
        ),
    ]



# Generated by Django 5.0.4 on 2024-06-18 16:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0058_datevaluedistribution_description_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='casetemplaterule',
            name='rule_values',
            field=models.JSONField(blank=True, null=True),
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-09 11:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0046_casetemplaterulevalue_target_field'),
    ]

    operations = [
        migrations.AddField(
            model_name='casetemplaterule',
            name='target_model',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-29 07:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0032_alter_medicationschedule_therapy_duration_d'),
    ]

    operations = [
        migrations.AddField(
            model_name='medicationindication',
            name='sources',
            field=models.ManyToManyField(to='endoreg_db.informationsource'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-24 09:20

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0014_pdftype_alter_rawpdffile_file_pdfmeta'),
    ]

    operations = [
        migrations.RenameField(
            model_name='rawpdffile',
            old_name='report_processed',
            new_name='state_report_processed',
        ),
        migrations.AddField(
            model_name='rawpdffile',
            name='center',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.center'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='rawpdffile',
            name='pdf_type',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.pdftype'),
            preserve_default=False,
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-09 13:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0051_remove_casetemplaterule_calling_rules_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='casetemplate',
            old_name='case_template_type',
            new_name='template_type',
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-24 14:57

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0018_reportreaderflag_reportreaderconfig'),
    ]

    operations = [
        migrations.AddField(
            model_name='pdftype',
            name='cut_off_above_lines',
            field=models.ManyToManyField(related_name='pdf_type_cut_off_above_lines', to='endoreg_db.reportreaderflag'),
        ),
        migrations.AddField(
            model_name='pdftype',
            name='cut_off_below_lines',
            field=models.ManyToManyField(related_name='pdf_type_cut_off_below_lines', to='endoreg_db.reportreaderflag'),
        ),
        migrations.AddField(
            model_name='pdftype',
            name='endoscopy_info_line',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='pdf_type_endoscopy_info_line', to='endoreg_db.reportreaderflag'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='pdftype',
            name='examiner_info_line',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='pdf_type_examiner_info_line', to='endoreg_db.reportreaderflag'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='pdftype',
            name='patient_info_line',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='pdf_type_patient_info_line', to='endoreg_db.reportreaderflag'),
            preserve_default=False,
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-09 11:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0045_casetemplaterulevalue_value_type'),
    ]

    operations = [
        migrations.AddField(
            model_name='casetemplaterulevalue',
            name='target_field',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-29 07:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0031_rename_adapt_to_liver_function_medication_adapt_to_age_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='medicationschedule',
            name='therapy_duration_d',
            field=models.FloatField(blank=True, null=True),
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-09 10:53

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0040_quizanswertype_quizquestiontype_quizquestion_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Gender',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('name_de', models.CharField(max_length=255, null=True)),
                ('name_en', models.CharField(max_length=255, null=True)),
                ('abbreviation', models.CharField(max_length=255, null=True)),
                ('description', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.AddField(
            model_name='patientmedication',
            name='medication_indication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='patient_medications', to='endoreg_db.medicationindication'),
        ),
        migrations.AlterField(
            model_name='examiner',
            name='gender',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.gender'),
        ),
        migrations.AlterField(
            model_name='patient',
            name='gender',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.gender'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-09 11:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0043_casetemplatetype_name_de_casetemplatetype_name_en'),
    ]

    operations = [
        migrations.AddField(
            model_name='casetemplateruletype',
            name='name_de',
            field=models.CharField(max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='casetemplateruletype',
            name='name_en',
            field=models.CharField(max_length=255, null=True),
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-02 16:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0023_ttoquestionnaire_alter_pdftype_endoscope_info_line'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ttoquestionnaire',
            name='infections',
        ),
        migrations.AddField(
            model_name='ttoquestionnaire',
            name='notes',
            field=models.TextField(default='Keine Bemerkungen', verbose_name='Bemerkungen'),
        ),
        migrations.AlterField(
            model_name='ttoquestionnaire',
            name='specimens_secured',
            field=models.BooleanField(default=False, verbose_name='Histologische Proben gesichert'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-09 11:23

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0044_casetemplateruletype_name_de_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='casetemplaterulevalue',
            name='value_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.casetemplaterulevaluetype'),
        ),
    ]



# Generated by Django 5.0.4 on 2024-06-24 15:36

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0065_rename__date_value_distribution_casetemplaterule_date_value_distribution_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='patientlabvalue',
            name='patient',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='lab_values', to='endoreg_db.patient'),
        ),
        migrations.CreateModel(
            name='PatientMedicationSchedule',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('medication', models.ManyToManyField(related_name='patient_medication_schedules', to='endoreg_db.patientmedication')),
                ('patient', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.patient')),
            ],
        ),
    ]



# Generated by Django 4.2.13 on 2024-05-30 04:16

import django.core.files.storage
import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0033_medicationindication_sources'),
    ]

    operations = [
        migrations.AlterField(
            model_name='rawpdffile',
            name='file',
            field=models.FileField(storage=django.core.files.storage.FileSystemStorage(location='/mnt/hdd-sensitive/Pseudo/import/pdf'), upload_to='raw_pdf/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])]),
        ),
    ]



# Generated by Django 5.0.4 on 2024-06-18 16:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0057_remove_datevaluedistribution_max_date_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='datevaluedistribution',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='name_de',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='name_en',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-10 15:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0006_rawvideofile_center_alter_videometa_processor'),
    ]

    operations = [
        migrations.AddField(
            model_name='rawvideofile',
            name='processor',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.endoscopyprocessor'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-26 09:59

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0025_event_alter_rawpdffile_file_patientevent'),
    ]

    operations = [
        migrations.CreateModel(
            name='Disease',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('name_de', models.CharField(blank=True, max_length=255, null=True)),
                ('name_en', models.CharField(blank=True, max_length=255, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='DiseaseClassification',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('name_de', models.CharField(blank=True, max_length=255, null=True)),
                ('name_en', models.CharField(blank=True, max_length=255, null=True)),
                ('disease', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.disease')),
            ],
        ),
        migrations.CreateModel(
            name='DiseaseClassificationChoice',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('name_de', models.CharField(blank=True, max_length=255, null=True)),
                ('name_en', models.CharField(blank=True, max_length=255, null=True)),
                ('disease_classification', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.diseaseclassification')),
            ],
        ),
        migrations.CreateModel(
            name='LabValue',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('name_de', models.CharField(blank=True, max_length=255, null=True)),
                ('name_en', models.CharField(blank=True, max_length=255, null=True)),
                ('default_unit', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.unit')),
            ],
        ),
        migrations.CreateModel(
            name='Medication',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('name_de', models.CharField(blank=True, max_length=255, null=True)),
                ('name_en', models.CharField(blank=True, max_length=255, null=True)),
                ('default_unit', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.unit')),
            ],
        ),
        migrations.CreateModel(
            name='Rule',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('name_de', models.CharField(blank=True, max_length=255, null=True)),
                ('name_en', models.CharField(blank=True, max_length=255, null=True)),
                ('description', models.TextField(blank=True, null=True)),
                ('attribute_key', models.CharField(max_length=255)),
            ],
            options={
                'verbose_name': 'Rule',
                'verbose_name_plural': 'Rules',
            },
        ),
        migrations.CreateModel(
            name='RuleAttributeDType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('name_de', models.CharField(blank=True, max_length=255, null=True)),
                ('name_en', models.CharField(blank=True, max_length=255, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='RuleType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('name_de', models.CharField(blank=True, max_length=255, null=True)),
                ('name_en', models.CharField(blank=True, max_length=255, null=True)),
            ],
            options={
                'verbose_name': 'Rule Type',
                'verbose_name_plural': 'Rule Types',
            },
        ),
        migrations.AddField(
            model_name='patientevent',
            name='last_update',
            field=models.DateTimeField(auto_now=True),
        ),
        migrations.CreateModel(
            name='Ruleset',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('name_de', models.CharField(blank=True, max_length=255, null=True)),
                ('name_en', models.CharField(blank=True, max_length=255, null=True)),
                ('rules', models.ManyToManyField(to='endoreg_db.rule')),
            ],
        ),
        migrations.AddField(
            model_name='rule',
            name='attribute_dtype',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.ruleattributedtype'),
        ),
        migrations.AddField(
            model_name='rule',
            name='rule_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.ruletype'),
        ),
        migrations.CreateModel(
            name='PatientMedication',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('name_de', models.CharField(blank=True, max_length=255, null=True)),
                ('name_en', models.CharField(blank=True, max_length=255, null=True)),
                ('dosage', models.JSONField()),
                ('active', models.BooleanField(default=True)),
                ('medication', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.medication')),
                ('unit', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.unit')),
            ],
            options={
                'verbose_name': 'Patient Medication',
                'verbose_name_plural': 'Patient Medications',
            },
        ),
        migrations.CreateModel(
            name='PatientLabValue',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.FloatField(blank=True, null=True)),
                ('value_str', models.CharField(blank=True, max_length=255, null=True)),
                ('date', models.DateTimeField()),
                ('lab_value', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.labvalue')),
                ('patient', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.patient')),
                ('unit', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.unit')),
            ],
        ),
        migrations.CreateModel(
            name='PatientDisease',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_date', models.DateField(blank=True, null=True)),
                ('end_date', models.DateField(blank=True, null=True)),
                ('last_update', models.DateTimeField(auto_now=True)),
                ('classification_choices', models.ManyToManyField(to='endoreg_db.diseaseclassificationchoice')),
                ('disease', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.disease')),
                ('patient', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.patient')),
            ],
        ),
    ]



# Generated by Django 5.0.4 on 2024-06-10 20:01

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0055_remove_casetemplaterule_rule_values_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='DateValueDistribution',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('min_date', models.DateField()),
                ('max_date', models.DateField()),
                ('distribution_type', models.CharField(choices=[('uniform', 'Uniform')], max_length=20)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='casetemplaterule',
            name='_date_value_distribution',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.datevaluedistribution'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-27 07:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0026_disease_diseaseclassification_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='labvalue',
            name='abbreviation',
            field=models.CharField(blank=True, max_length=10, null=True),
        ),
        migrations.AddField(
            model_name='labvalue',
            name='default_normal_range',
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='labvalue',
            name='normal_range_age_dependent',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='labvalue',
            name='normal_range_gender_dependent',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='labvalue',
            name='normal_range_special_case',
            field=models.BooleanField(default=False),
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-02 16:03

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0022_alter_pdftype_endoscope_info_line'),
    ]

    operations = [
        migrations.CreateModel(
            name='TtoQuestionnaire',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('patient_name', models.CharField(max_length=255, verbose_name='Identifikation des Patienten (Name)')),
                ('birth_date', models.DateField(verbose_name='Geburtsdatum')),
                ('emergency_patient', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Notfallpatient/kürzlich untersuchter Patient (Verzicht auf Team-Time-Out möglich)')),
                ('consent_signed', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Einverständniserklärung unterschrieben (Arzt, Patient)')),
                ('documents_present', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Alle Dokumente liegen vor (Labor, Befunde, etc.)')),
                ('communication_possible', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Kommunikation mit Patient möglich')),
                ('pregnancy', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Schwangerschaft')),
                ('asa_classification_checked', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='ASA-Klassifikation/Komorbidität geprüft')),
                ('previous_anesthesia_complications', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Komplikationen bei bisherigen Narkosen?')),
                ('last_meal_over_6_hours_ago', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Zeitpunkt letzte Mahlzeit > 6 Stunden')),
                ('allergies', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Allergien, welche?')),
                ('outpatient_accompaniment_post_sedation', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Nur bei ambulanter Vorstellung: Begleitung nach Sedierung?')),
                ('work_incapacity_certificate', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Arbeitsunfähigkeitsbescheinigung')),
                ('dental_prosthesis', models.BooleanField(default=False, verbose_name='Zahnprothese')),
                ('glasses', models.BooleanField(default=False, verbose_name='Brille')),
                ('implants', models.BooleanField(default=False, verbose_name='Implantate')),
                ('hearing_aids', models.BooleanField(default=False, verbose_name='Hörgeräte')),
                ('infections', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Infektionen')),
                ('anticoagulants_ass', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Antikoagulation, ASS')),
                ('blood_pressure_medication', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Blutdruckmedikamente')),
                ('metal_implants', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Metallimplantate')),
                ('pacemaker_icd', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Herzschrittmacher/ICD')),
                ('copd', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='COPD')),
                ('liver_cirrhosis', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Leberzirrhose')),
                ('ibd', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='CED (Chronisch entzündliche Darmerkrankungen)')),
                ('radiation', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Bestrahlung')),
                ('glaucoma', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Glaukom')),
                ('surgeries', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='OP´s')),
                ('team_introduction', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Teamvorstellung mit Name und Aufgabe')),
                ('instruments_available', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Notwendige Instrumente vorhanden?')),
                ('monitoring_medications_equipment_checked', models.CharField(choices=[('yes', 'Ja'), ('no', 'Nein')], max_length=3, verbose_name='Monitoring, Medikamente, Equipment zum Atemwegsmanagement zur Verfügung und überprüft?')),
                ('complete_documentation_inclusive_care_notes', models.TextField(verbose_name='Vollständige Dokumentation inklusive Hinweise für Nachsorge')),
                ('specimens_secured', models.BooleanField(default=False, verbose_name='Präparate versorgt')),
                ('patient_condition_documented', models.TextField(verbose_name='Patientenzustand dokumentiert (je nach Ausgangszustand)')),
            ],
        ),
        migrations.AlterField(
            model_name='pdftype',
            name='endoscope_info_line',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='pdf_type_endoscopy_info_line', to='endoreg_db.reportreaderflag'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-10 15:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0007_rawvideofile_processor'),
    ]

    operations = [
        migrations.RenameField(
            model_name='rawvideofile',
            old_name='frames_required',
            new_name='state_frames_required',
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-10 13:07

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0004_rename_hash_rawvideofile_video_hash'),
    ]

    operations = [
        migrations.CreateModel(
            name='FFMpegMeta',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('duration', models.FloatField(blank=True, null=True)),
                ('width', models.IntegerField(blank=True, null=True)),
                ('height', models.IntegerField(blank=True, null=True)),
                ('frame_rate', models.FloatField(blank=True, null=True)),
                ('video_codec', models.CharField(blank=True, max_length=50, null=True)),
                ('audio_codec', models.CharField(blank=True, max_length=50, null=True)),
                ('audio_channels', models.IntegerField(blank=True, null=True)),
                ('audio_sample_rate', models.IntegerField(blank=True, null=True)),
            ],
        ),
        migrations.RemoveField(
            model_name='videoimportmeta',
            name='center',
        ),
        migrations.RemoveField(
            model_name='videoimportmeta',
            name='endoscope',
        ),
        migrations.RemoveField(
            model_name='videoimportmeta',
            name='processor',
        ),
        migrations.CreateModel(
            name='VideoMeta',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('center', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.center')),
                ('endoscope', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.endoscope')),
                ('ffmpeg_meta', models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.ffmpegmeta')),
                ('import_meta', models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.videoimportmeta')),
                ('processor', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.endoscopyprocessor')),
            ],
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='video_meta',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.videometa'),
        ),
    ]



# Generated by Django 5.0.4 on 2024-06-10 19:51

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0054_multiplecategoricalvaluedistribution_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='casetemplaterule',
            name='rule_values',
        ),
        migrations.AddField(
            model_name='casetemplaterule',
            name='_multiple_categorical_value_distribution',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.multiplecategoricalvaluedistribution'),
        ),
        migrations.AddField(
            model_name='casetemplaterule',
            name='_numerical_value_distribution',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.numericvaluedistribution'),
        ),
        migrations.AddField(
            model_name='casetemplaterule',
            name='_single_categorical_value_distribution',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.singlecategoricalvaluedistribution'),
        ),
        migrations.AddField(
            model_name='casetemplaterule',
            name='parent_model',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='casetemplaterulevaluetype',
            name='distribution_type',
            field=models.CharField(choices=[('single_categorical', 'single_categorical'), ('multiple_categorical', 'multiple_categorical'), ('numeric', 'numeric')], default='single_categorical', max_length=255),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='casetemplaterulevaluetype',
            name='name_de',
            field=models.CharField(max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='casetemplaterulevaluetype',
            name='name_en',
            field=models.CharField(max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='casetemplaterule',
            name='value_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.casetemplaterulevaluetype'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-10 14:46

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0005_ffmpegmeta_remove_videoimportmeta_center_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='rawvideofile',
            name='center',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.center'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='videometa',
            name='processor',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.endoscopyprocessor'),
        ),
    ]



# Generated by Django 5.0.4 on 2024-06-24 15:49

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0066_alter_patientlabvalue_patient_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='medicationindication',
            name='indication_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='medication_indications', to='endoreg_db.medicationindicationtype'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-10 17:44

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0008_rename_frames_required_rawvideofile_state_frames_required'),
    ]

    operations = [
        migrations.CreateModel(
            name='SensitiveMeta',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('examination_date', models.DateField(blank=True, null=True)),
                ('patient_first_name', models.CharField(blank=True, max_length=255, null=True)),
                ('patient_last_name', models.CharField(blank=True, max_length=255, null=True)),
                ('patient_dob', models.DateField(blank=True, null=True)),
                ('endoscope_type', models.CharField(blank=True, max_length=255, null=True)),
                ('endoscope_serial_number', models.CharField(blank=True, max_length=255, null=True)),
            ],
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='sensitive_meta',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.sensitivemeta'),
        ),
    ]



# Generated by Django 5.0.4 on 2024-06-18 15:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0056_datevaluedistribution_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='datevaluedistribution',
            name='max_date',
        ),
        migrations.RemoveField(
            model_name='datevaluedistribution',
            name='min_date',
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='date_max',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='date_mean',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='date_min',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='date_std_dev',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='mode',
            field=models.CharField(choices=[('date', 'Date'), ('timedelta', 'Timedelta')], default=None, max_length=20),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='timedelta_days_max',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='timedelta_days_mean',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='timedelta_days_min',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='timedelta_days_std_dev',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='datevaluedistribution',
            name='distribution_type',
            field=models.CharField(choices=[('uniform', 'Uniform'), ('normal', 'Normal')], max_length=20),
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-25 21:31

import django.core.files.storage
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0024_remove_ttoquestionnaire_infections_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Event',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True)),
                ('name_de', models.CharField(blank=True, max_length=100, null=True)),
                ('name_en', models.CharField(blank=True, max_length=100, null=True)),
                ('description', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.AlterField(
            model_name='rawpdffile',
            name='file',
            field=models.FileField(storage=django.core.files.storage.FileSystemStorage(location='/home/agl-admin/case-generator/agl_case_generator/erc_data/raw_pdf'), upload_to='raw_pdf/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])]),
        ),
        migrations.CreateModel(
            name='PatientEvent',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date_start', models.DateField()),
                ('date_end', models.DateField(blank=True, null=True)),
                ('description', models.TextField(blank=True, null=True)),
                ('event', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.event')),
                ('patient', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.patient')),
            ],
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-23 15:39

import django.core.files.storage
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import pathlib


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0012_rawvideofile_prediction_dir_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='RawPdfFile',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file', models.FileField(storage=django.core.files.storage.FileSystemStorage(location=pathlib.PurePosixPath('/mnt/hdd-sensitive/Pseudo/import/report')), upload_to='raw_pdf/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])])),
                ('pdf_hash', models.CharField(max_length=255, unique=True)),
                ('report_processed', models.BooleanField(default=False)),
                ('text', models.TextField(blank=True, null=True)),
                ('anonymized_text', models.TextField(blank=True, null=True)),
                ('raw_meta', models.JSONField(blank=True, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('sensitive_meta', models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='raw_pdf_file', to='endoreg_db.sensitivemeta')),
            ],
        ),
    ]



# Generated by Django 5.0.4 on 2024-06-18 19:07

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0060_labvalue__default_date_value_distribution_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='patientlabvalue',
            name='date',
        ),
        migrations.AddField(
            model_name='patientlabvalue',
            name='datetime',
            field=models.DateTimeField(auto_now_add=True, default=datetime.datetime(2024, 6, 18, 19, 7, 56, 929033, tzinfo=datetime.timezone.utc)),
            preserve_default=False,
        ),
    ]



# Generated by Django 5.0.4 on 2024-06-18 19:02

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0059_casetemplaterule_rule_values'),
    ]

    operations = [
        migrations.AddField(
            model_name='labvalue',
            name='_default_date_value_distribution',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='default_date_value_distribution', to='endoreg_db.datevaluedistribution'),
        ),
        migrations.AddField(
            model_name='labvalue',
            name='_default_multiple_categorical_value_distribution',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='default_multiple_categorical_value_distribution', to='endoreg_db.multiplecategoricalvaluedistribution'),
        ),
        migrations.AddField(
            model_name='labvalue',
            name='_default_numerical_value_distribution',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='default_numerical_value_distribution', to='endoreg_db.numericvaluedistribution'),
        ),
        migrations.AddField(
            model_name='labvalue',
            name='_default_single_categorical_value_distribution',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='default_single_categorical_value_distribution', to='endoreg_db.singlecategoricalvaluedistribution'),
        ),
        migrations.AlterField(
            model_name='patientlabvalue',
            name='patient',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='lab_values', to='endoreg_db.patient'),
        ),
        migrations.AlterField(
            model_name='patientlabvalue',
            name='sample',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='values', to='endoreg_db.patientlabsample'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-23 16:45

import django.core.files.storage
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0013_rawpdffile'),
    ]

    operations = [
        migrations.CreateModel(
            name='PdfType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
            ],
        ),
        migrations.AlterField(
            model_name='rawpdffile',
            name='file',
            field=models.FileField(storage=django.core.files.storage.FileSystemStorage(location='/mnt/hdd-sensitive/Pseudo/import/pdf'), upload_to='raw_pdf/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])]),
        ),
        migrations.CreateModel(
            name='PdfMeta',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateField()),
                ('time', models.TimeField()),
                ('pdf_hash', models.CharField(max_length=255, unique=True)),
                ('pdf_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.pdftype')),
            ],
        ),
    ]



# Generated by Django 4.2.11 on 2024-03-10 17:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0009_sensitivemeta_rawvideofile_sensitive_meta'),
    ]

    operations = [
        migrations.RenameField(
            model_name='sensitivemeta',
            old_name='endoscope_serial_number',
            new_name='endoscope_sn',
        ),
    ]
